var indexSectionsWithContent =
{
  0: "123456789_abcdefghijklmnopqrstuvxz",
  1: "cgiks",
  2: "ir",
  3: "adfgikmqsz",
  4: "_acdefghijklmnopqrstuvxz",
  5: "abcdfghikqsxz",
  6: "i",
  7: "i",
  8: "_dik",
  9: "dilm"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "defines",
  9: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Macros",
  9: "Pages"
};

